@@ -2,6 +2,7 @@ from celery import shared_task
 
 from eveuniverse.core.esitools import is_esi_online
 from eveuniverse.models import EveEntity
+from eveuniverse.tasks import update_unresolved_eve_entities
 
 from allianceauth.services.hooks import get_extension_logger
 from app_utils.logging import LoggerAddTag
@@ -59,6 +60,13 @@ def run_character_sync(sync_char_pk: int):
     synced_character.run_sync()
 
 
+@shared_task
+def character_delete_all_contacts(sync_char_pk: int):
+    """Delete contacts of this character."""
+    synced_character = SyncedCharacter.objects.get(pk=sync_char_pk)
+    synced_character.delete_all_contacts()
+
+
 @shared_task
 def sync_all_wars():
     """Sync all wars from ESI."""
@@ -70,6 +78,7 @@ def sync_all_wars():
         )
         for war_id in fetch_active_war_ids_esi:
             run_war_sync.apply_async(args=[war_id], priority=DEFAULT_TASK_PRIORITY)
+    update_unresolved_eve_entities.apply_async(priority=DEFAULT_TASK_PRIORITY)
 
 
 @shared_task
