@@ -47,18 +47,19 @@ class TestTasksE2E(NoSocketsTestCase):
         mock_esi.client.Contacts.get_alliances_alliance_id_contacts.return_value = (
             BravadoOperationStub(alliance_contacts)
         )
-        esi_character_contacts = EsiCharacterContactsStub()
-        esi_character_contacts.setup_esi_mock(mock_esi)
+        esi_character_contacts = EsiCharacterContactsStub.create(
+            sync_character.character.character_id, mock_esi
+        )
         # when
         run_manager_sync.delay(manager_pk=manager.pk)
         # then
-        character_contacts = esi_character_contacts._contacts[
-            sync_character.character.character_id
-        ]
-        self.assertEqual(character_contacts[some_alliance_contact.id].standing, 5)
-        self.assertEqual(character_contacts[manager.alliance.alliance_id].standing, 10)
+        expected = {
+            EsiContact.from_eve_entity(some_alliance_contact, standing=5),
+            EsiContact(manager.alliance.alliance_id, "alliance", standing=10),
+        }
+        self.assertSetEqual(esi_character_contacts.contacts(), expected)
         self.assertNotIn(
-            sync_character.character.character_id, character_contacts.keys()
+            sync_character.character.character_id, esi_character_contacts.contact_ids()
         )
 
     @patch(MODELS_PATH + ".STANDINGSSYNC_REPLACE_CONTACTS", True)
@@ -82,13 +83,12 @@ class TestTasksE2E(NoSocketsTestCase):
             BravadoOperationStub(alliance_contacts)
         )
         war_target_label = EsiContactLabel(1, "WAR TARGETS")
-        esi_character_contacts = EsiCharacterContactsStub()
-        esi_character_contacts.setup_esi_mock(mock_esi)
-        esi_character_contacts.setup_labels(character.id, [war_target_label])
+        esi_character_contacts = EsiCharacterContactsStub.create(
+            character.id, mock_esi, labels=[war_target_label]
+        )
         # when
         run_manager_sync.delay(manager_pk=manager.pk)
         # then
-        result = esi_character_contacts.contacts(sync_character.character.character_id)
         expected = {
             EsiContact.from_eve_entity(some_alliance_contact, standing=5),
             EsiContact(
@@ -100,7 +100,7 @@ class TestTasksE2E(NoSocketsTestCase):
                 war.aggressor, standing=-10, label_ids=[war_target_label.id]
             ),
         }
-        self.assertSetEqual(result, expected)
+        self.assertSetEqual(esi_character_contacts.contacts(), expected)
 
     @patch(MODELS_PATH + ".STANDINGSSYNC_REPLACE_CONTACTS", True)
     @patch(MODELS_PATH + ".STANDINGSSYNC_ADD_WAR_TARGETS", True)
@@ -125,20 +125,18 @@ class TestTasksE2E(NoSocketsTestCase):
             BravadoOperationStub(alliance_contacts)
         )
         war_target_label = EsiContactLabel(1, "WAR TARGETS")
-        esi_character_contacts = EsiCharacterContactsStub()
-        esi_character_contacts.setup_esi_mock(mock_esi)
-        esi_character_contacts.setup_contacts(
+        esi_character_contacts = EsiCharacterContactsStub.create(
             character.id,
-            [
+            mock_esi,
+            contacts=[
                 EsiContact.from_eve_entity(ally, standing=5),
                 EsiContact.from_eve_entity(some_character_contact, standing=10),
             ],
+            labels=[war_target_label],
         )
-        esi_character_contacts.setup_labels(character.id, [war_target_label])
         # when
         run_manager_sync.delay(manager_pk=manager.pk)
         # then
-        result = esi_character_contacts.contacts(sync_character.character.character_id)
         expected = {
             EsiContact.from_eve_entity(some_alliance_contact, standing=5),
             EsiContact(
@@ -153,7 +151,7 @@ class TestTasksE2E(NoSocketsTestCase):
                 ally, standing=-10, label_ids=[war_target_label.id]
             ),
         }
-        self.assertSetEqual(result, expected)
+        self.assertSetEqual(esi_character_contacts.contacts(), expected)
 
     @patch(MODELS_PATH + ".STANDINGSSYNC_REPLACE_CONTACTS", False)
     @patch(MODELS_PATH + ".STANDINGSSYNC_ADD_WAR_TARGETS", True)
@@ -178,12 +176,11 @@ class TestTasksE2E(NoSocketsTestCase):
             BravadoOperationStub(alliance_contacts)
         )
         war_target_label = EsiContactLabel(1, "WAR TARGETS")
-        esi_character_contacts = EsiCharacterContactsStub()
-        esi_character_contacts.setup_esi_mock(mock_esi)
-        esi_character_contacts.setup_labels(character.id, [war_target_label])
-        esi_character_contacts.setup_contacts(
+        esi_character_contacts = EsiCharacterContactsStub.create(
             character.id,
-            [
+            mock_esi,
+            labels=[war_target_label],
+            contacts=[
                 EsiContact.from_eve_entity(ally, standing=5),
                 EsiContact.from_eve_entity(some_character_contact, standing=10),
             ],
@@ -191,9 +188,8 @@ class TestTasksE2E(NoSocketsTestCase):
         # when
         run_manager_sync.delay(manager_pk=manager.pk)
         # then
-        result = esi_character_contacts.contacts(sync_character.character.character_id)
         expected = {
-            EsiContact.from_eve_entity(alliance, standing=10),
+            # EsiContact.from_eve_entity(alliance, standing=10),
             EsiContact.from_eve_entity(
                 war.defender, standing=-10, label_ids=[war_target_label.id]
             ),
@@ -201,9 +197,9 @@ class TestTasksE2E(NoSocketsTestCase):
                 ally, standing=-10, label_ids=[war_target_label.id]
             ),
             EsiContact.from_eve_entity(some_character_contact, standing=10),
-            EsiContact.from_eve_entity(some_alliance_contact, standing=5),
+            # EsiContact.from_eve_entity(some_alliance_contact, standing=5),
         }
-        self.assertSetEqual(result, expected)
+        self.assertSetEqual(esi_character_contacts.contacts(), expected)
 
 
 class TestUI(NoSocketsTestCase):
@@ -212,7 +208,7 @@ class TestUI(NoSocketsTestCase):
         user = UserMainSyncerFactory()
         self.client.force_login(user)
         # when
-        response = self.client.get("/standingssync/")
+        response = self.client.get("/standingssync/characters")
         # then
         self.assertEqual(response.status_code, 200)
 
@@ -226,6 +222,29 @@ class TestUI(NoSocketsTestCase):
         SyncedCharacterFactory(manager=sync_manager)
         self.client.force_login(user)
         # when
-        response = self.client.get("/standingssync/")
+        response = self.client.get("/standingssync/characters")
+        # then
+        self.assertEqual(response.status_code, 200)
+
+    def test_should_open_wars_page_w_sync_manager(self):
+        # given
+        user = UserMainSyncerFactory()
+        alliance = EveAllianceInfo.objects.get(
+            alliance_id=user.profile.main_character.alliance_id
+        )
+        sync_manager = SyncManagerFactory(alliance=alliance)
+        SyncedCharacterFactory(manager=sync_manager)
+        self.client.force_login(user)
+        # when
+        response = self.client.get("/standingssync/wars")
+        # then
+        self.assertEqual(response.status_code, 200)
+
+    def test_should_open_wars_page_wo_sync_manager(self):
+        # given
+        user = UserMainSyncerFactory()
+        self.client.force_login(user)
+        # when
+        response = self.client.get("/standingssync/wars")
         # then
         self.assertEqual(response.status_code, 200)
